@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
 ## This file is part of Videoporama
@@ -296,21 +295,56 @@ class QGraphicsRectTextItem(QtGui.QGraphicsRectItem):
       self.ZValue          = ZValue
       #Init item
       super(QGraphicsRectTextItem,self).__init__(self.x*xmax,self.y*ymax,xmax*w,ymax*h,parent)
-      self.FontName        = "DejaVu Sans"    # font name
-      self.FontSize        = 12               # font size
-      self.FontColor       = "ffffff"         # font color
-      self.FontShadowColor = "5f5f5f"         # font shadow color
-      self.IsBold          = False            # if bold mode
-      self.IsItalic        = False            # if Italic mode
-      self.IsUnderline     = False            # if Underline mode
-      self.HAlign          = 1                # Horizontal alignement : 0=left, 1=center, 2=right, 3=justif
-      self.VAlign          = 1                # Vertical alignement : 0=up, 1=center, 2=bottom
-      self.StyleText       = 1                # Style : 0=normal, 1=outerline, 2=shadow up-left, 3=shadow up-right, 4=shadow bt-left, 5=shadow bt-right
-      self.BackgroundForm  = 1                # Type of the form : 0=None, 1=Rectangle, 2=Ellipse
-      self.BackgroundStyle = 0                # Type of the background color : 0=Solid, 1=Transparent 90% 2=Transparent 80%..., 10=Transparent
-      self.BackgroundColor = "afafaf"         # Color of the background of the form
-      self.PenSize         = 1                # Width of the pen of the form
-      self.PenColor        = "ffffff"         # Color of the pen of the form
+      self.VideoporamaInstance=TextDlg.VideoporamaInstance
+      if TextDlg.TypeText=="Image":
+        self.FontName        = self.VideoporamaInstance.TBackGFontName         # font name
+        self.FontSize        = self.VideoporamaInstance.TBackGFontSize         # font size
+        self.FontColor       = self.VideoporamaInstance.TBackGFontColor        # font color
+        self.FontShadowColor = self.VideoporamaInstance.TBackGFontShadowColor  # font shadow color
+        self.IsBold          = self.VideoporamaInstance.TBackGIsBold           # if bold mode
+        self.IsItalic        = self.VideoporamaInstance.TBackGIsItalic         # if Italic mode
+        self.IsUnderline     = self.VideoporamaInstance.TBackGIsUnderline      # if Underline mode
+        self.HAlign          = self.VideoporamaInstance.TBackGHAlign           # Horizontal alignement : 0=left, 1=center, 2=right, 3=justif
+        self.VAlign          = self.VideoporamaInstance.TBackGVAlign           # Vertical alignement : 0=up, 1=center, 2=bottom
+        self.StyleText       = self.VideoporamaInstance.TBackGStyleText        # Style : 0=normal, 1=outerline, 2=shadow up-left, 3=shadow up-right, 4=shadow bt-left, 5=shadow bt-right
+        self.BackgroundForm  = self.VideoporamaInstance.TBackGBackgroundForm   # Type of the form : 0=None, 1=Rectangle, 2=Ellipse
+        self.BackgroundStyle = self.VideoporamaInstance.TBackGBackgroundStyle  # Type of the background color : 0=Solid, 1=Transparent 90% 2=Transparent 80%..., 10=Transparent
+        self.BackgroundColor = self.VideoporamaInstance.TBackGBackgroundColor  # Color of the background of the form
+        self.PenSize         = self.VideoporamaInstance.TBackGPenSize          # Width of the pen of the form
+        self.PenColor        = self.VideoporamaInstance.TBackGPenColor         # Color of the pen of the form
+      elif TextDlg.TypeText=="ZoomPoint":
+        self.FontName        = self.VideoporamaInstance.TShotFontName         # font name
+        self.FontSize        = self.VideoporamaInstance.TShotFontSize         # font size
+        self.FontColor       = self.VideoporamaInstance.TShotFontColor        # font color
+        self.FontShadowColor = self.VideoporamaInstance.TShotFontShadowColor  # font shadow color
+        self.IsBold          = self.VideoporamaInstance.TShotIsBold           # if bold mode
+        self.IsItalic        = self.VideoporamaInstance.TShotIsItalic         # if Italic mode
+        self.IsUnderline     = self.VideoporamaInstance.TShotIsUnderline      # if Underline mode
+        self.HAlign          = self.VideoporamaInstance.TShotHAlign           # Horizontal alignement : 0=left, 1=center, 2=right, 3=justif
+        self.VAlign          = self.VideoporamaInstance.TShotVAlign           # Vertical alignement : 0=up, 1=center, 2=bottom
+        self.StyleText       = self.VideoporamaInstance.TShotStyleText        # Style : 0=normal, 1=outerline, 2=shadow up-left, 3=shadow up-right, 4=shadow bt-left, 5=shadow bt-right
+        self.BackgroundForm  = self.VideoporamaInstance.TShotBackgroundForm   # Type of the form : 0=None, 1=Rectangle, 2=Ellipse
+        self.BackgroundStyle = self.VideoporamaInstance.TShotBackgroundStyle  # Type of the background color : 0=Solid, 1=Transparent 90% 2=Transparent 80%..., 10=Transparent
+        self.BackgroundColor = self.VideoporamaInstance.TShotBackgroundColor  # Color of the background of the form
+        self.PenSize         = self.VideoporamaInstance.TShotPenSize          # Width of the pen of the form
+        self.PenColor        = self.VideoporamaInstance.TShotPenColor         # Color of the pen of the form
+      elif TextDlg.TypeText=="Overlaid":
+        self.FontName        = self.VideoporamaInstance.TOverlaidFontName         # font name
+        self.FontSize        = self.VideoporamaInstance.TOverlaidFontSize         # font size
+        self.FontColor       = self.VideoporamaInstance.TOverlaidFontColor        # font color
+        self.FontShadowColor = self.VideoporamaInstance.TOverlaidFontShadowColor  # font shadow color
+        self.IsBold          = self.VideoporamaInstance.TOverlaidIsBold           # if bold mode
+        self.IsItalic        = self.VideoporamaInstance.TOverlaidIsItalic         # if Italic mode
+        self.IsUnderline     = self.VideoporamaInstance.TOverlaidIsUnderline      # if Underline mode
+        self.HAlign          = self.VideoporamaInstance.TOverlaidHAlign           # Horizontal alignement : 0=left, 1=center, 2=right, 3=justif
+        self.VAlign          = self.VideoporamaInstance.TOverlaidVAlign           # Vertical alignement : 0=up, 1=center, 2=bottom
+        self.StyleText       = self.VideoporamaInstance.TOverlaidStyleText        # Style : 0=normal, 1=outerline, 2=shadow up-left, 3=shadow up-right, 4=shadow bt-left, 5=shadow bt-right
+        self.BackgroundForm  = self.VideoporamaInstance.TOverlaidBackgroundForm   # Type of the form : 0=None, 1=Rectangle, 2=Ellipse
+        self.BackgroundStyle = self.VideoporamaInstance.TOverlaidBackgroundStyle  # Type of the background color : 0=Solid, 1=Transparent 90% 2=Transparent 80%..., 10=Transparent
+        self.BackgroundColor = self.VideoporamaInstance.TOverlaidBackgroundColor  # Color of the background of the form
+        self.PenSize         = self.VideoporamaInstance.TOverlaidPenSize          # Width of the pen of the form
+        self.PenColor        = self.VideoporamaInstance.TOverlaidPenColor         # Color of the pen of the form
+
       self.Text            = ""               # Plain text
       #define Mouse cursor
       self.setCursor(Qt.SizeAllCursor)
@@ -424,7 +458,7 @@ class DefTextDlg(QDialog,Ui_DefTextDlg) :
       # Load correct image with correct size
       self.PrepareImage()
       # Connect correct OK function depending on text type
-      if self.TypeText=="Image":       self.VideoporamaInstance.qtapp.connect(self.Ok,SIGNAL("pressed()"),self.VideoporamaInstance.TAB_Image_DefTextOk)
+      if self.TypeText=="Image":       self.VideoporamaInstance.qtapp.connect(self.Ok,SIGNAL("pressed()"),self.VideoporamaInstance.SEQ_DefTextOk)
       elif self.TypeText=="ZoomPoint": self.VideoporamaInstance.qtapp.connect(self.Ok,SIGNAL("pressed()"),self.VideoporamaInstance.TableZoomPoint_DefZoomPointTextOk)
       elif self.TypeText=="Overlaid":  self.VideoporamaInstance.qtapp.connect(self.Ok,SIGNAL("pressed()"),self.VideoporamaInstance.TAB_Montage_DefTextOk)
       # Preparing QGraphicsScene for interactive user action
@@ -526,12 +560,34 @@ class DefTextDlg(QDialog,Ui_DefTextDlg) :
       self.VideoporamaInstance.qtapp.connect(self.plainTextEdit,SIGNAL("textChanged()"),self.plainTextEditChange)
       self.VideoporamaInstance.qtapp.connect(self.HelpBt,SIGNAL("pressed()"),self.onHelp)
       self.SetupInterface()
-      
+      #Restore Window Size & Position (if needed)
+      if self.VideoporamaInstance.RestoreWindowState=="1" and self.VideoporamaInstance.TextBoxWinRx>0:
+        self.move(self.VideoporamaInstance.TextBoxWinRx,self.VideoporamaInstance.TextBoxWinRy)
+        self.resize(self.VideoporamaInstance.TextBoxWinRw,self.VideoporamaInstance.TextBoxWinRh)
+        if self.VideoporamaInstance.TextBoxIsMaximized!=0: self.showMaximized()
+
     def onHelp(self):
-      self.docw=DocHelp(self.VideoporamaInstance,self)
-      self.docw.SetSourceDocument(self.VideoporamaInstance.qtapp.translate("Documentation","en-textbox.html"))
+      self.docw=DocHelp(self.VideoporamaInstance,self.VideoporamaInstance.qtapp.translate("Documentation","en-textbox.html"),self)
       self.docw.show() 
 
+    def SaveWindowPosition(self):
+      # Save Windows size/position on exit
+      if self.isMaximized():  
+        self.VideoporamaInstance.TextBoxIsMaximized=1
+      else : 
+        self.VideoporamaInstance.TextBoxIsMaximized=0
+        if isWindows():
+          size=self.frameGeometry()
+          self.VideoporamaInstance.TextBoxWinRx = size.x()
+          self.VideoporamaInstance.TextBoxWinRy = size.y()
+          size=self.geometry()
+        else:
+          size=self.geometry()
+          self.VideoporamaInstance.TextBoxWinRx = size.x()-1 #It's not good but X11 don't give the real information !
+          self.VideoporamaInstance.TextBoxWinRy = size.y()-self.VideoporamaInstance.win.menuBar().height()-5 #It's not good but X11 don't give the real information !
+        self.VideoporamaInstance.TextBoxWinRw = size.width()
+        self.VideoporamaInstance.TextBoxWinRh = size.height()
+
     def onCancel(self):
       self.close()
 
@@ -577,11 +633,11 @@ class DefTextDlg(QDialog,Ui_DefTextDlg) :
 
       # Load correct image depending on text type
       if self.TypeText=="Image":
-        self.image = self.timelineImage.ToRenderImageForDisplay(-1,self.xmax,self.ymax,fx=0,fy=0,fw=0,fh=0,StopAtFullImage=True,DontRenderImageText=True,DontRenderZoomPointText=True)
+        self.image,Unused = self.timelineImage.ToRenderImageForDisplay(-1,self.xmax,self.ymax,fx=0,fy=0,fw=0,fh=0,StopAtFullImage=True,DontRenderImageText=True,DontRenderZoomPointText=True)
       elif self.TypeText=="ZoomPoint":
-        self.image = self.timelineImage.ToRenderImageForDisplay(self.itemNum,self.xmax,self.ymax,fx=0,fy=0,fw=0,fh=0,StopAtFullImage=False,DontRenderImageText=False,DontRenderZoomPointText=True)
+        self.image,Unused = self.timelineImage.ToRenderImageForDisplay(self.itemNum,self.xmax,self.ymax,fx=0,fy=0,fw=0,fh=0,StopAtFullImage=False,DontRenderImageText=False,DontRenderZoomPointText=True)
       elif self.TypeText=="Overlaid":
-        self.image,unusexmax,unuseymax=LoadAndPrepareImage("",self.VideoporamaInstance.ConfAutoRotate,self.VideoporamaInstance.ConfBgFile,self.VideoporamaInstance.ConfBgColor,self.VideoporamaInstance.imgformat)
+        self.image,unusexmax,unuseymax=LoadAndPrepareImage("",self.VideoporamaInstance.ConfAutoRotate,self.VideoporamaInstance.ConfBgFile,self.VideoporamaInstance.ConfBgColor,self.VideoporamaInstance.imgformat,1)
         self.image=self.image.scaled(self.xmax,self.ymax,Qt.IgnoreAspectRatio,Qt.SmoothTransformation)
 
     def ForcePaint(self):
