@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
 # This file is part of Videoporama
@@ -570,7 +569,7 @@ class DefZoomPointDlg(QDialog,Ui_DefZoomPointDlg) : #OK QT4
       self.VideoporamaInstance.qtapp.connect(self.HelpBt,SIGNAL("pressed()"),self.onHelp)
 
       # Prepare image
-      self.image = self.timelineImage.ToRenderImageForDisplay(0,self.xmax,self.ymax,0,0,0,0,True,DontRenderImageText=False,DontRenderZoomPointText=True)
+      self.image,Unused = self.timelineImage.ToRenderImageForDisplay(0,self.xmax,self.ymax,0,0,0,0,True,DontRenderImageText=False,DontRenderZoomPointText=True)
 
       # Calc guides positions
       VirtX=float(self.item.ImageItem.RealImageSizeWidth)
@@ -598,10 +597,32 @@ class DefZoomPointDlg(QDialog,Ui_DefZoomPointDlg) : #OK QT4
         self.MagnetY2=self.MagnetY1+(float(self.item.ImageItem.RealImageSizeHeight)*Ratio)
 
       self.SetupInterface()
+      #Restore Window Size & Position (if needed)
+      if self.VideoporamaInstance.RestoreWindowState=="1" and self.VideoporamaInstance.ZoomBoxWinRx>0:
+        self.move(self.VideoporamaInstance.ZoomBoxWinRx,self.VideoporamaInstance.ZoomBoxWinRy)
+        self.resize(self.VideoporamaInstance.ZoomBoxWinRw,self.VideoporamaInstance.ZoomBoxWinRh)
+        if self.VideoporamaInstance.ZoomBoxIsMaximized!=0: self.showMaximized()
+
+    def SaveWindowPosition(self):
+      # Save Windows size/position on exit
+      if self.isMaximized():  
+        self.VideoporamaInstance.TextBoxIsMaximized=1
+      else : 
+        self.VideoporamaInstance.TextBoxIsMaximized=0
+        if isWindows():
+          size=self.frameGeometry()
+          self.VideoporamaInstance.ZoomBoxWinRx = size.x()
+          self.VideoporamaInstance.ZoomBoxWinRy = size.y()
+          size=self.geometry()
+        else:
+          size=self.geometry()
+          self.VideoporamaInstance.ZoomBoxWinRx = size.x()-1 #It's not good but X11 don't give the real information !
+          self.VideoporamaInstance.ZoomBoxWinRy = size.y()-self.VideoporamaInstance.win.menuBar().height()-5 #It's not good but X11 don't give the real information !
+        self.VideoporamaInstance.ZoomBoxWinRw = size.width()
+        self.VideoporamaInstance.ZoomBoxWinRh = size.height()
 
     def onHelp(self):
-      self.docw=DocHelp(self.VideoporamaInstance,self)
-      self.docw.SetSourceDocument(self.VideoporamaInstance.qtapp.translate("Documentation","en-zoombox.html"))
+      self.docw=DocHelp(self.VideoporamaInstance,self.VideoporamaInstance.qtapp.translate("Documentation","en-zoombox.html"),self)
       self.docw.show() 
 
     def onCancel(self):
@@ -662,7 +683,7 @@ class DefZoomPointDlg(QDialog,Ui_DefZoomPointDlg) : #OK QT4
           self.MagnetY2=self.MagnetY1+(float(self.item.ImageItem.RealImageSizeHeight)*Ratio)
 
         # Prepare image
-        self.image = self.timelineImage.ToRenderImageForDisplay(0,self.xmax,self.ymax,0,0,0,0,True,DontRenderImageText=False,DontRenderZoomPointText=True)
+        self.image,Unused = self.timelineImage.ToRenderImageForDisplay(0,self.xmax,self.ymax,0,0,0,0,True,DontRenderImageText=False,DontRenderZoomPointText=True)
         # Update all
         self.SetupInterface()
 
