@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
 # This file is part of Videoporama
@@ -30,11 +29,177 @@ from __builtin__ import hex as hexp
 from math import *
 import Image
 import StringIO
+import subprocess
 
-try :
-  import pyexiv2
-  exivData = True
-except : exivData = False
+def isWindows():
+  try:
+    WinVersion=QSysInfo().WindowsVersion
+    return True
+  except:
+    return False
+
+
+def buildSound(VideoporamaInstance, urlIn, urlOut, TstartV, duration, vol=256, fadeIn=0.0, fadeOut=0.0) :
+  """Function to compose sound with fade in, fade out, from movie sound ou sound file"""
+  command = u"\"%sffmpeg\" -vn -ss %f -t %f -i \"%s\" -vol %d -f s16le -acodec pcm_s16le -ar 48000 -ac 2 - | \"%ssox\" -t raw -c 2 -r 48000 -b 16 --endian little -e signed-integer - -t wav -c 2 -r 48000 -b 16 --endian little -e signed-integer \"%s\" fade h %f %f %f " % ( \
+                  VideoporamaInstance.I, \
+                  TstartV, \
+                  duration, \
+                  urlIn, \
+                  vol, \
+                  VideoporamaInstance.S, \
+                  urlOut, \
+                  fadeIn, \
+                  duration, \
+                  fadeOut)
+  if isWindows() :
+    Process = subprocess.Popen(command.encode('iso-8859-1'),shell=True,stdin=file('nul','a'),stderr=file('nul','a'),stdout=file('nul','a'))
+  else:
+    Process = subprocess.Popen(command.encode('utf-8'),shell=True)
+  Process.wait()
+  if not QFile(urlOut).exists() :
+    return False
+  return True
+    
+	
+#Execute a commande and wait for it finished. Return True if OK
+def ExecuteCommande(Commande,Parent=None):
+  BoolReturn=False
+  print "Commande="+unicode(Commande)
+  if isWindows() : 
+    Commande=u"\""+unicode(Commande)+"\""
+    Process = subprocess.Popen(Commande.encode('iso-8859-1'),shell=True,stdin=file('nul','a'),stderr=file('nul','a'),stdout=file('nul','a'))
+  else:
+    Process = subprocess.Popen(Commande.encode('utf-8'),shell=True)
+  Process.wait()
+  return True
+
+#Transform a Path to a relatif path accordind to ProjectFilePathName
+def MakeRelatif(ProjectFilePathName,PathToTransform):
+  if ProjectFilePathName=="" or PathToTransform=="": return PathToTransform
+  else : 
+    RelatifBasePath=QFileInfo(ProjectFilePathName).absolutePath()
+    return unicode(QDir(RelatifBasePath).relativeFilePath(PathToTransform))
+
+#Transform a Path to an absolut path accordind to ProjectFilePathName
+def MakeAbsolut(ProjectFilePathName,PathToTransform):
+  if ProjectFilePathName=="" or PathToTransform=="":
+    None
+  else : 
+    RelatifBasePath=QFileInfo(ProjectFilePathName).absolutePath()
+    PathToTransform=unicode(QDir().cleanPath(QDir(RelatifBasePath).absoluteFilePath(PathToTransform)))
+  return PathToTransform
+
+#--------------------------------------------------------------------
+#Function call to draw a ruller + zone define by start/end
+#  CustomWidget   QLabel use for drawing
+#  Start          QDateTime containing the start of the zone
+#  End            QDateTime containing the start of the zone
+#  TotalDuration  QDateTime containing the total duration
+#--------------------------------------------------------------------
+def DrawMovieRuller(CustomWidget,Start,End,TotalDuration):
+  Width        = CustomWidget.width()
+  Height       = CustomWidget.height()
+  MinTickSpace = 30                       # Not less than 30 pixels between to tick
+
+  # Prepare QPainter
+  Img=QImage(QSize(Width,Height),QImage.Format_ARGB32_Premultiplied)
+  Painter=QPainter(Img)
+  OptionText=QTextOption(Qt.AlignCenter)
+  Font=QFont("DejaVu Sans",int(7),QFont.Normal,QFont.StyleNormal)
+  Painter.setFont(Font)
+  Painter.fillRect(QRect(0,0,Width,Height),QColor(Qt.white))
+
+  if QTime(0,0,0).msecsTo(TotalDuration)!=0:
+    # Draw zone
+    if Start!=None and End!=None:
+      PosStart=int(float(Width)*(float(QTime(0,0,0).msecsTo(Start))/float(QTime(0,0,0).msecsTo(TotalDuration))))
+      PosEnd  =int(float(Width)*(float(QTime(0,0,0).msecsTo(End))/float(QTime(0,0,0).msecsTo(TotalDuration))))
+      Painter.fillRect(QRect(PosStart,12,PosEnd-PosStart,Height-14),QColor(Qt.blue))
+
+    # Now : Draw line and texte of the ruller
+
+    #Define an echelle
+    Duration=float(QTime(0,0,0).msecsTo(TotalDuration))/float(1000)   # Calc duration in sec (float)
+
+    # Test for MinTickSpace pixels between 2 ticks
+    if (float(Width)/float(Duration))>MinTickSpace:
+      Ech     ="S"                                # Use sec as echelle
+      SizeTick=float(Width)/Duration
+    elif (float(Width)/float(Duration/10))>MinTickSpace:
+      Ech="10S"                                   # Use 10 sec as echelle
+      SizeTick=float(Width)/float(Duration/10)
+    elif (float(Width)/float(Duration/60))>MinTickSpace:
+      Ech="M"                                     # Use minute as echelle
+      SizeTick=float(Width)/float(Duration/60)
+    elif (float(Width)/float(Duration/600))>MinTickSpace:
+      Ech="10M"                                   # Use 10 minute as echelle
+      SizeTick=float(Width)/float(Duration/600)
+    else:
+      Ech="H"                                     # Use hour as echelle
+      SizeTick=float(Width)/float(Duration/3600)
+
+    # Calc NbrTick to draw
+    NbrTick=float(Width)/SizeTick
+
+    TimeSec =float(0)
+    TimeMin =float(0)
+    TimeHour=float(0)
+
+    Cur=float(0)
+    while Cur<Width:
+      
+      Painter.drawLine(int(Cur*SizeTick),10,int(Cur*SizeTick),Height)
+      
+      # Draw text
+      if Ech=="H" : Text=str(int(TimeHour)).rjust(2,'0')+":"+str(int(TimeMin)).rjust(2,'0')
+      else :        Text=str(int(TimeMin)).rjust(2,'0')+":"+str(int(TimeSec)).rjust(2,'0')
+      Painter.drawText(int(Cur*SizeTick),9,Text)
+
+      # Draw intermediate tick and then increment time depending on echelle
+      if Ech=="S":
+        TimeSec+=1
+      elif Ech=="10S":
+        if (MinTickSpace*2)<SizeTick: # Test if we can draw an intermediate tick
+          Painter.drawLine(int((Cur+0.5)*SizeTick),10,int((Cur+0.5)*SizeTick),Height)
+          # Draw text
+          Text=str(int(TimeMin)).rjust(2,'0')+":"+str(int(TimeSec+5)).rjust(2,'0')
+          Painter.drawText(int((Cur+0.5)*SizeTick),9,Text)
+        TimeSec+=10
+      elif Ech=="M":
+        if (MinTickSpace*2)<SizeTick: # Test if we can draw an intermediate tick
+          Painter.drawLine(int((Cur+0.5)*SizeTick),10,int((Cur+0.5)*SizeTick),Height)
+          # Draw text
+          Text=str(int(TimeMin)).rjust(2,'0')+":"+str(int(TimeSec+30)).rjust(2,'0')
+          Painter.drawText(int((Cur+0.5)*SizeTick),9,Text)
+        TimeMin+=1
+      elif Ech=="10M":
+        if (MinTickSpace*2)<SizeTick: # Test if we can draw an intermediate tick
+          Painter.drawLine(int((Cur+0.5)*SizeTick),10,int((Cur+0.5)*SizeTick),Height)
+          # Draw text
+          Text=str(int(TimeMin+5)).rjust(2,'0')+":"+str(int(TimeSec)).rjust(2,'0')
+          Painter.drawText(int((Cur+0.5)*SizeTick),9,Text)
+        TimeMin+=10
+      else:
+        if (MinTickSpace*2)<SizeTick: # Test if we can draw an intermediate tick
+          Painter.drawLine(int((Cur+0.5)*SizeTick),10,int((Cur+0.5)*SizeTick),Height)
+          # Draw text
+          Text=str(int(TimeHour)).rjust(2,'0')+":"+str(int(TimeMin+30)).rjust(2,'0')
+          Painter.drawText(int((Cur+0.5)*SizeTick),9,Text)
+        TimeHour+=1
+
+      # Adjust time
+      if TimeSec>59:
+        TimeSec-=60
+        TimeMin+=1
+      if TimeMin>59:
+        TimeMin-=60
+        TimeHour+=1
+
+      # Go to next tick
+      Cur=Cur+1
+  Painter.end()
+  CustomWidget.setPixmap(QPixmap.fromImage(Img))
 
 #Function for text conversion to keep specials caracters in XML
 def ToHTML(Text):
@@ -55,21 +220,29 @@ def FromHTML(Text):
   return NewText
 
 #Load image and place it to a background (in image source size)
-def LoadAndPrepareImage(FilePathName,ConfAutoRotate,bgfile,bgcolor,imgwide):
+def LoadAndPrepareImage(FilePathName,ConfAutoRotate,bgfile,bgcolor,imgwide,Orientation,SourceImage=None):
     # Load source image from disk and prepare it with background and correct geometry
     if FilePathName!="" : 
-      SourceImage=QImage(FilePathName)
+      if SourceImage==None : SourceImage=QImage(FilePathName)
       # Obtain the exif data to determine if the image should be rotated
-      if ConfAutoRotate=="1":
-        SourceImage=ExivProcess(SourceImage,FilePathName)
+      if ConfAutoRotate=="1": SourceImage=ExivProcess(SourceImage,Orientation)
+      # It's time to calcul xmax and ymax use in pixel display mode
+      SourceXMax=float(SourceImage.width())
+      SourceYMax=float(SourceImage.height())
     else :
       if imgwide==1 : xmax=1920
       else :          xmax=1440
       ymax=1080
-      SourceImage=QImage(QSize(xmax,ymax),QImage.Format_ARGB32_Premultiplied)
-      p=QPainter(SourceImage)
-      p.fillRect(QRect(0,0,xmax,ymax),toqcolor(QString(bgcolor).toInt(16)[0]))
-      p.end()
+      if bgfile != "" :
+        # Create Background Item backgroundi
+        bkgpix = QImage(bgfile)
+        # Scale image to correct without aspect ratio
+        SourceImage=bkgpix.scaled(xmax,ymax,Qt.IgnoreAspectRatio,Qt.SmoothTransformation)
+      else :
+        SourceImage=QImage(QSize(xmax,ymax),QImage.Format_ARGB32_Premultiplied)
+        p=QPainter(SourceImage)
+        p.fillRect(QRect(0,0,xmax,ymax),toqcolor(QString(bgcolor).toInt(16)[0]))
+        p.end()
 
     # It's time to calcul xmax and ymax use in pixel display mode
     SourceXMax=float(SourceImage.width())
@@ -131,8 +304,8 @@ def ApplyTextToQImage(SourceImage,xmlPoint,DrawSelectionBox=False):
     if xmlText.length>0 :
       xmlText =xmlText[0]
       TextNum =0
-      while xmlText.getElementsByTagName(u"Text-"+unicode(TextNum)).length>0 :
-        CurXMLText      =xmlText.getElementsByTagName(u"Text-"+unicode(TextNum))[0]
+      while xmlText.getElementsByTagName(u"Text-"+str(TextNum)).length>0 :
+        CurXMLText      =xmlText.getElementsByTagName(u"Text-"+str(TextNum))[0]
         x               =float(CurXMLText.getAttribute(u"X"))
         y               =float(CurXMLText.getAttribute(u"Y"))
         w               =float(CurXMLText.getAttribute(u"W"))
@@ -284,28 +457,24 @@ def ApplyTextToQImage(SourceImage,xmlPoint,DrawSelectionBox=False):
 #----------------------------------------------------------------------------------------------------------------------
 # Rotate Source image if needed depend on exivData
 #----------------------------------------------------------------------------------------------------------------------
-def ExivProcess(SourceImage,urlim):
-    # Obtain the exif data to determine if the image should be rotated
-    if exivData :
-      # Note: The image function takes a standard string so we use str() to convert the QString
-      try:
-        exif = pyexiv2.Image(unicode(urlim))
-        exif.readMetadata()
-        orientation = exif['Exif.Image.Orientation']
-      except:
-        orientation = None
-      # Only two orientations are currently supported (images rotated left or right by 90 degrees)
-      # A good explanation of the exif orientation tag is available at http://sylvana.net/jpegcrop/exif_orientation.html
-      if orientation == 8:
-        #Rotating image anti-clockwise by 90 degrees...'
-        matrix=QMatrix()
-        matrix.rotate( -90 )
-        SourceImage=SourceImage.transformed(matrix)
-      elif orientation == 6:
-        #Rotating image clockwise by 90 degrees...'
-        matrix=QMatrix()
-        matrix.rotate( 90 )
-        SourceImage=SourceImage.transformed(matrix)
+def ExivProcess(SourceImage,orientation):
+    # Use exif orientation to determine if the image should be rotated
+    # A good explanation of the exif orientation tag is available at http://jpegclub.org/exif_orientation.html
+    if orientation == 8:
+      #Rotating image anti-clockwise by 90 degrees...'
+      matrix=QMatrix()
+      matrix.rotate(-90)
+      SourceImage=SourceImage.transformed(matrix)
+    elif orientation == 3:
+      #Rotating image clockwise by 180 degrees...'
+      matrix=QMatrix()
+      matrix.rotate(180)
+      SourceImage=SourceImage.transformed(matrix)
+    elif orientation == 6:
+      #Rotating image clockwise by 90 degrees...'
+      matrix=QMatrix()
+      matrix.rotate(90)
+      SourceImage=SourceImage.transformed(matrix)
     return SourceImage
 
 #----------------------------------------------------------------------------------------------------------------------
@@ -340,7 +509,7 @@ def colortohex(color):
   rr=hexp(r)
   gg=hexp(g)
   bb=hexp(b)
-  colorh=unicode(rr.strip("0x").upper().rjust(2,"0")+gg.strip("0x").upper().rjust(2,"0")+bb.strip("0x").upper().rjust(2,"0")).encode('utf-8')
+  colorh=str(rr.strip("0x").upper().rjust(2,"0")+gg.strip("0x").upper().rjust(2,"0")+bb.strip("0x").upper().rjust(2,"0")).encode('utf-8')
   return colorh
 
 def toqcolor(color): #OK QT4
@@ -352,10 +521,10 @@ def toqcolor(color): #OK QT4
   
 def frameToTime(frameNbr, ips=25) :  
   sec=float(frameNbr) / ips
-  seconde=unicode(sec % 60).split(".")
+  seconde=str(sec % 60).split(".")
   minute=int(sec / 60)
   heure=int(minute / 60)
-  timesnd="%s:%s:%s.%s" % (unicode(heure).rjust(2,'0'),unicode(minute).rjust(2,'0'),seconde[0].rjust(2,'0'),seconde[1].ljust(3,'0')[0:3])
+  timesnd="%s:%s:%s.%s" % (str(heure).rjust(2,'0'),str(minute).rjust(2,'0'),seconde[0].rjust(2,'0'),seconde[1].ljust(3,'0')[0:3])
   return timesnd
 
 #----------------------------------------------------------------------------------------------------------------------
@@ -365,10 +534,10 @@ def lumaList() :
   lumask=QStringList()
   lumal=QStringList()
   z=0
-  b=os.listdir(os.getcwdu()+os.sep+u"luma/")
+  b=os.listdir(os.getcwdu()+QDir().separator().toAscii()+u"luma/")
   for c in b :
     if not c.startswith(".") :
-      lumask.append(os.getcwdu()+os.sep+u"luma/"+c)
+      lumask.append(os.getcwdu()+QDir().separator().toAscii()+u"luma/"+c)
       lumal.append(c)
       z+=1
   # sort list
@@ -421,22 +590,13 @@ def randomTransi() :
 #-------------------------------------------------------------------------------------
 def validatePath(PathToCheck,AddSep=True):
     if PathToCheck=="" : return PathToCheck
-    if os.name == 'nt' : 
-      i=0
-      Path=unicode("")
-      while i<len(PathToCheck):
-        if PathToCheck[i]==u'/':
-          Path=Path+u'\\'
-        else:
-          Path=Path+PathToCheck[i]
-        i+=1
-      if AddSep==True :
-        if Path[len(Path)-1]!=os.sep : Path=Path+os.sep
+    if AddSep==True :
+      if PathToCheck[len(PathToCheck)-1]!=QDir().separator().toAscii() : PathToCheck=PathToCheck+QDir().separator().toAscii()
+    Path=QDir().toNativeSeparators(PathToCheck)
+    if isWindows() : 
       Path=unicode(Path).encode('iso-8859-1')
     else:
       Path=unicode(PathToCheck)
-      if AddSep==True :
-        if Path[len(Path)-1]!=os.sep : Path=Path+os.sep
     return Path
 
 #-------------------------------------------------------------------------------------
@@ -444,7 +604,7 @@ def validatePath(PathToCheck,AddSep=True):
 #-------------------------------------------------------------------------------------
 #version for subprocess.Popen
 def validateCommande(CommandeToCheck,AddWindowsExe=True):
-    if os.name == 'nt' : 
+    if isWindows() : 
       i=0
       Commande=unicode("")
       while i<len(CommandeToCheck):
@@ -460,29 +620,11 @@ def validateCommande(CommandeToCheck,AddWindowsExe=True):
       Commande=unicode(CommandeToCheck).encode('utf-8')
     return Commande
 
-#-------------------------------------------------------------------------------------
-# Function use to check if a directory exist (windows/linux)
-#-------------------------------------------------------------------------------------
-def IsPathExist(Path):
-    if os.name == 'nt' : 
-      i=0
-      PathToTest=""
-      while i<len(Path):
-        if Path[i]=="\\":
-          PathToTest=PathToTest+"\\\\"
-        else:
-          PathToTest=PathToTest+Path[i]
-        i+=1
-      PathToTest=unicode(PathToTest).encode('iso-8859-1')
-      return os.path.exists(PathToTest)
-    else:
-      return os.path.exists(unicode(Path).encode('utf-8'))
-
 #-------------------------------------------------------------------------------------
 # Function use to check if a directory is writable (windows/linux)
 #-------------------------------------------------------------------------------------
 def IsPathWritable(Path):
-    if os.name == 'nt' : 
+    if isWindows() : 
       i=0
       PathToTest=""
       while i<len(Path):
@@ -500,7 +642,7 @@ def IsPathWritable(Path):
 # Function use to check if a binary file exist (windows/linux)
 #-------------------------------------------------------------------------------------
 def IsBinaryFileExist(Path):
-    if os.name == 'nt' : 
+    if isWindows() : 
       i=0
       PathToTest=""
       while i<len(Path):
@@ -520,7 +662,7 @@ def IsBinaryFileExist(Path):
 # Function use to check if a file exist (windows/linux)
 #-------------------------------------------------------------------------------------
 def IsFileExist(Path):
-    if os.name == 'nt' : 
+    if isWindows() : 
       i=0
       PathToTest=""
       while i<len(Path):
@@ -542,7 +684,7 @@ def LoadValueFromXMLFile(XMLObject,NameValue,DefaultValue,Tree="configuration"):
   try:
     ReturnValue=XMLObject.getElementsByTagName(NameValue)[0].childNodes[0].nodeValue
   except:
-    ReturnValue=str(DefaultValue)
+    ReturnValue=unicode(DefaultValue)
     if ReturnValue!="":
       doc=Document()
       xmlchild = doc.createElement(unicode(NameValue))
@@ -567,13 +709,13 @@ def UpdateConfigurationXMLFile(XMLObject,NameValue,Value,Tree="configuration"):
   else:
     try: 
       doc=Document()
-      xmlchild = doc.createTextNode(unicode(Value))
+      xmlchild = doc.createTextNode(Value)
       xmltag=XMLObject.getElementsByTagName(NameValue)[0]
       xmltag.replaceChild(xmlchild,xmltag.childNodes[0])
     except :
       if Value!="": 
-        xmlchild = doc.createElement(unicode(NameValue))
-        xmlchild.appendChild(doc.createTextNode(unicode(Value)))
+        xmlchild = doc.createElement(NameValue)
+        xmlchild.appendChild(doc.createTextNode(Value))
         xmltag=XMLObject.getElementsByTagName(Tree)[0]
         xmltag.appendChild(xmlchild)
 
@@ -671,7 +813,7 @@ def colortohex(color):
   rr=hexp(r)
   gg=hexp(g)
   bb=hexp(b)
-  colorh=unicode(rr.strip("0x").upper().rjust(2,"0")+gg.strip("0x").upper().rjust(2,"0")+bb.strip("0x").upper().rjust(2,"0"))
+  colorh=str(rr.strip("0x").upper().rjust(2,"0")+gg.strip("0x").upper().rjust(2,"0")+bb.strip("0x").upper().rjust(2,"0"))
   return colorh
 
 #-------------------------------------------------------------------------------------
