@@ -1,7 +1,6 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-# This file is part of Videoporama but it was an new version of the EKD file
+# This file is part of Videoporama but it was an adated version of the EKD file
 # Videoporama is a program to make diaporama export in video file
 # Copyright (C) 2007-2010  Olivier Ponchaut <opvg@edpnet.be>
 
@@ -28,29 +27,36 @@ from PyQt4.QtGui import *
 from PyQt4.QtCore import *
 
 
-def getParamVideo(cheminVideoEntre, parameter):
+def getParamVideo(cheminVideoEntre, parameter, cheminMP):
   """Renvoie un ou plusieurs paramètres de la vidéo sous forme de flottant.
   La variable «cheminVideoEntre» est le chemin de la vidéo de type unicode.
   La variable «parameter» est un tuple de paramètres à renvoyer.
   La dernière variable renvoyée est un tuple des lignes de log"""
   
-  cheminVideoEntre = cheminVideoEntre.encode("UTF8")
+  cheminVideoEntre = unicode(cheminVideoEntre)
   
   # Condition pour détection windows
   if os.name == 'nt':
-    recupDonneesVideo = os.popen('mplayer.exe -vo null -ao null -identify -frames 0 '+ "\"" + cheminVideoEntre + "\"").readlines()
+    command = unicode(cheminMP)+u"mplayer.exe -vo null -ao null -identify -frames 0 \"" + cheminVideoEntre + u"\""
   # Condition pour détection Linux ou MacOSX
   elif os.name in ['posix', 'mac']:
-    recupDonneesVideo = os.popen('mplayer ' +"\""+ cheminVideoEntre +\
-    "\" -vo null -ao null -frames 0 -identify '$@' 2>/dev/null").readlines()
+    command = unicode(cheminMP)+u"mplayer \""+ cheminVideoEntre +u"\" -vo null -ao null -frames 0 -identify '$@' 2>/dev/null"
+
+  processus = QProcess()
+  processus.start(command)
+  if (not processus.waitForStarted()):
+    raise (u"Erreur de récupération des informations")
+  if ( not processus.waitForFinished()):
+    raise (u"Erreur de récupération des informations")
+  recupDonneesVideo = QString(processus.readAllStandardOutput())
   
   lstValeurs = []
   log = []
   
-  for ligne in recupDonneesVideo:
+  for ligne in recupDonneesVideo.split("\n") :
     try:
       # On veut que les caractères non ASCII s'affichent correctement pour les noms de fichiers
-      log.append(ligne.decode("UTF8"))
+      log.append(ligne)
     except UnicodeDecodeError:
       print "Traitement d'exception unicode au niveau de getParamVideo() probablement dûe aux méta-données de la vidéo"
       log.append(ligne)
@@ -66,26 +72,30 @@ def getParamVideo(cheminVideoEntre, parameter):
   
   return lstValeurs
 
-def getVideoLength(cheminVideoEntre):
+def getVideoLength(cheminVideoEntre, cheminMP):
   "Retourne la durée de la vidéo. L'argument doit être de type unicode"
-  return getParamVideo(cheminVideoEntre, ["ID_LENGTH"])
+  return getParamVideo(cheminVideoEntre, ["ID_LENGTH"], cheminMP)
 
-def getVideoSize(cheminVideoEntre):
+def getVideoSize(cheminVideoEntre, cheminMP):
   "Retourne la taille de la vidéo. L'argument doit être de type unicode"
-  return getParamVideo(cheminVideoEntre, ["ID_VIDEO_WIDTH", "ID_VIDEO_HEIGHT"])
+  return getParamVideo(cheminVideoEntre, ["ID_VIDEO_WIDTH", "ID_VIDEO_HEIGHT"], cheminMP)
 
-def getVideoFPS(cheminVideoEntre):
+def getVideoFPS(cheminVideoEntre, cheminMP):
   "Retourne le nombre de trames par seconde de la vidéo. L'argument doit être de type unicode"
-  return getParamVideo(cheminVideoEntre, ["ID_VIDEO_FPS"])
+  return getParamVideo(cheminVideoEntre, ["ID_VIDEO_FPS"], cheminMP)
 
-def getVideoRatio(cheminVideoEntre):
+def getVideoRatio(cheminVideoEntre, cheminMP):
   "Retourne l'aspect ratio de la vidéo. L'argument doit être de type unicode"
-  return getParamVideo(cheminVideoEntre, ["ID_VIDEO_ASPECT"])
+  return getParamVideo(cheminVideoEntre, ["ID_VIDEO_ASPECT"], cheminMP)
 
+def getAudioInfo(cheminVideoEntre, cheminMP):
+  """Retourne la durée de la piste audio, le sample rate et le nombre de canaux de la partie audio"""
+  return getParamVideo(cheminVideoEntre, ['ID_LENGTH','ID_AUDIO_RATE','ID_AUDIO_NCH'], cheminMP)
+    
 
 class TracerChrono(QWidget):
   """On trace le temps car il ne s'affiche pas bien autrement pour certaines configurations"""
-  TAILLE = "0:00:00:000"
+  TAILLE = "00:00:00.000"
   def __init__(self):
     # parent nous permettra d'accéder à la valeur du curseur
     QWidget.__init__(self)
@@ -203,8 +213,6 @@ class Mplayer(QDialog):
     
     self.taille = taille
 
-    print "self.taille avant lecture :", self.taille, type(self.taille)
-    
     #=== Widgets ===#
     
     self.icone_lire=QIcon("icons" + os.sep + "player_play.png")
@@ -346,7 +354,7 @@ class Mplayer(QDialog):
       if self.choicewide.isChecked() :
         self.setRatio(16.0/9.0)
       if self.choiceone.isChecked() :
-        dim=getVideoSize(unicode(self.listeVideos[0]))
+        dim=getVideoSize(unicode(self.listeVideos[0]), self.VideoporamaInstance.MP)
         self.setRatio(dim[0]/dim[1])
       self.defRatio()
     else :
@@ -357,7 +365,7 @@ class Mplayer(QDialog):
     self.sizeMplayer()
     
   def changeRatio(self,video) :
-    rv = getVideoRatio(video)
+    rv = getVideoRatio(video, self.VideoporamaInstance.MP)
     if rv[0]==0.0 and type(rv[1])==float :
       rat = rv[1]
     else :
@@ -371,15 +379,34 @@ class Mplayer(QDialog):
       self.setRatio(4.0/3.0)
     elif rat < 1.3 and rat != 0.0 :
       self.choiceone.setChecked(True)
-      dim=getVideoSize(video)
+      dim=getVideoSize(video, self.VideoporamaInstance.MP)
       self.setRatio(dim[0]/dim[1])
     else :
       self.choicenorm.setChecked(True)
       self.setRatio(4.0/3.0)
+    info = getAudioInfo(video, self.VideoporamaInstance.MP)
+    try :
+      self.dureeVideo = info[2] 
+      self.channels = info[4] 
+      self.sampleRate = info[3]
+    except :
+      self.dureeVideo = 0.0
+      self.channels = 0.0
+      self.sampleRate = 0.0
       
   def sizeMplayer(self) :
     self.cibleVideo.setFixedHeight(int(self.cibleVideo.width()/self.ratio))
 
+  def setAudio(self,au) :
+    if au :
+      self.cibleVideo.hide()
+      if "conf" in self.__dict__ :
+        self.conf.hide()
+    else :
+      self.cibleVideo.show()
+      if "conf" in self.__dict__ :
+        self.conf.show()
+                            
   def ouvrirVideo(self):
     """Ouverture de la boîte de dialogue de fichiers"""
     txt = self.VideoporamaInstance.qtapp.translate("MPlayerDlg","Video files")
@@ -396,6 +423,11 @@ class Mplayer(QDialog):
 
     chemin = unicode(self.listeVideos[0])
 
+  def setFileToPlay(self, fileName, debutFin=(0,0)) :
+    self.debutFin = debutFin
+    #print debutFin
+    self.listeVideos = [fileName]
+    self.changeRatio(unicode(fileName))
   
   def demarrerMPlayer(self):
     """démarrage de mplayer avec les arguments choisis"""
@@ -425,9 +457,16 @@ class Mplayer(QDialog):
     else:
       # reinterpret_cast<qlonglong> obligatoire, winId() ne se laissant pas convertir gentiment ;)
       args << "-wid" << self.cibleVideo.winId().__hex__()
-      args << "-vo" << "directx:noaccel"
+      if self.VideoporamaInstance.AEROCOMPATIBILITY==True :
+        args << "-vo" << "directx:noaccel"
+      else :
+        args << "-vo" << "gl:glfinish"
       #args << "-vo" << "gl" # alternative
-
+   
+    #print "debutFin = ", self.debutFin
+    # Ajout début - durée aux args
+    args << "-ss" << str(self.debutFin[0])
+  
     # chemin de la vidéo
     args << self.listeVideos
     
@@ -542,7 +581,7 @@ class Mplayer(QDialog):
         #print "self.debutFin", self.debutFin[1], type(self.debutFin[1])
         temps = float("%.1f" %self.temps)
         #print "temps", temps, type(temps), '\n'
-        if self.debutFin!=(0,0) and self.debutFin[1]==temps:
+        if (self.debutFin[0]!=0 or self.debutFin[1]!=0) and self.debutFin[1]<=temps:
           self.arretMPlayer()
           return
         ## Modifié le 28/05/2009 : On augmente la précision du slider ###############
@@ -579,7 +618,7 @@ class Mplayer(QDialog):
     mn = str(temps.minute()).zfill(2)
     s = str(temps.second()).zfill(2)
     ms = str(temps.msec()).zfill(3)
-    chrono = str(temps.hour())+':'+mn+':'+s+':'+ms
+    chrono = str(temps.hour())+':'+mn+':'+s+'.'+ms
     self.tempsChrono.num = chrono
     self.tempsChrono.repaint()
     ###########################################################################################################
@@ -631,11 +670,10 @@ class Mplayer(QDialog):
           return True
     
     self.mplayerProcess.write("quit\n") # arrêt de la vidéo
-    
     # au cas où mplayer ne s'arrêterait pas au bout de 3 sec
-    if not self.mplayerProcess.waitForFinished(3000):
-      QMessageBox.critical(self, self.VideoporamaInstance.qtapp.translate("MPlayerDlg","Warning"), self.VideoporamaInstance.qtapp.translate("MPlayerDlg","Error when stoping mplayer"))
-      return False
+    #if not self.mplayerProcess.waitForFinished(3000):
+      #QMessageBox.critical(self, self.VideoporamaInstance.qtapp.translate("MPlayerDlg","Warning"), self.VideoporamaInstance.qtapp.translate("MPlayerDlg","Error when stoping mplayer"))
+      #return False
     
     self.slider.setEnabled(False) # évite un bogue
     #self.slider.setEnabled(True)
